@@ -2,7 +2,10 @@
    Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
    James Bowman, Craig Franklin
 
-    Copyright (C) 2014-2016 Molnar Karoly
+   Copyright (C) 2014-2016 Molnár Károly
+
+   Dump COFF file contents option.
+   Copyright (C) 2019 Gonzalo Pérez de Olaguer Córdoba <salo@gpoc.es>
 
 This file is part of gputils.
 
@@ -56,6 +59,9 @@ typedef struct {
 enum {
   OPT_MPASM_COMPATIBLE = 0x100,
   OPT_STRICT_OPTIONS
+#ifdef GPUTILS_DEBUG
+  , OPT_DUMP_COFF
+#endif
 };
 
 static struct option longopts[] =
@@ -93,6 +99,9 @@ static struct option longopts[] =
   { "mpasm-compatible",          no_argument,       NULL, OPT_MPASM_COMPATIBLE },
   { "preprocess",                required_argument, NULL, 'P' },
   { "macro-dereference",         no_argument,       NULL, 'X' },
+#ifdef GPUTILS_DEBUG
+  { "dump-coff",                 no_argument,       NULL, OPT_DUMP_COFF },
+#endif
   { NULL,                        no_argument,       NULL, '\0' }
 };
 
@@ -110,6 +119,9 @@ _show_usage(void)
   printf("  -C, --old-coff                 Use old Microchip COFF format.\n");
   printf("  -d, --debug                    Output debug messages.\n");
   printf("  -D SYM=VAL, --define SYM=VAL   Define SYM with value VAL.\n");
+#ifdef GPUTILS_DEBUG
+  printf("      --dump-coff                Dump COFF file contents.\n");
+#endif
   printf("  -e [ON|OFF], --expand [ON|OFF] Macro expansion.\n");
   printf("  -f, --full-address             Show full address in .lst file at the memory map region.\n");
   printf("  -g, --debug-info               Use debug directives for COFF.\n");
@@ -151,9 +163,9 @@ _show_usage(void)
          "                                 (W or F and A or B) and the \"Undefined Processor\" messages.\n"
          "                                 The \"strict messages\" have higher priority than the warnings.\n"
          "                                 (See: -w [0|1|2]) [0]\n");
-  printf("                                     0: Is the default. No strict messages.\n"
+  printf("                                     0: Is the default. No strict messages.\n"
          "                                     1: Show warning messages if one of is missing.\n"
-         "                                     2: Show error messages if one of is missing.\n");
+         "                                     2: Show error messages if one of is missing.\n");
   printf("  -t, --sdcc-dev14-list          Help to the extension of the pic14devices.txt file\n"
          "                                 in the sdcc project. Using by itself, displays the all\n"
          "                                 '14', '14e' and '14f' devices. Along with the '-p'\n"
@@ -367,10 +379,10 @@ _pic16e_lister(pic_processor_t Processor)
   if ((addr0 > 0) && (addr1 >= addr0)) {
     printf("configrange 0x%06X 0x%06X\n", addr0, addr1);
     gp_cfg_brief_device(dev, "configword  ", class->addr_digits, class->config_digits,
-                        (Processor->pic16e_flags & PIC16E_FLAG_J_SUBFAMILY) ? true : false);
+                        (Processor->cpu_flags & CPU_18FJ_FAMILY) ? true : false);
   }
 
-  if (Processor->pic16e_flags & PIC16E_FLAG_HAVE_EXTINST) {
+  if (Processor->cpu_flags & CPU_HAVE_EXTINST) {
     printf("XINST       1\n");
   }
 
@@ -855,6 +867,12 @@ process_args(int argc, char *argv[])
         state.mpasm_compatible = true;
         break;
 
+#ifdef GPUTILS_DEBUG
+      case OPT_DUMP_COFF:
+        gp_dump_coff = true;
+        break;
+#endif
+
       case OPT_STRICT_OPTIONS:
         break;
     } /* switch (c) */
@@ -963,7 +981,6 @@ assemble(void)
     state.cmd_line.processor = true;
   }
 
-  symbol_list_init();
   _set_global_constants();
 
   state.pass = 1;
@@ -1013,7 +1030,6 @@ assemble(void)
     state.cmd_line.processor = true;
   }
 
-  symbol_list_reset();
   _set_global_constants();
 
   open_src(state.src_file_name, false);
@@ -1064,7 +1080,6 @@ assemble(void)
 
   file_free();
   gp_bitarray_delete(&state.badrom);
-  symbol_list_free();
   gpmsg_close();
   return (((state.num.errors > 0) || (gp_num_errors > 0)) ? EXIT_FAILURE : EXIT_SUCCESS);
 }
