@@ -2,7 +2,10 @@
    Copyright (C) 2001, 2002, 2003, 2004, 2005
    Craig Franklin
 
-    Copyright (C) 2016 Molnar Karoly
+   Copyright (C) 2016 Molnár Károly
+
+   Report missing symbols in gp_cofflink_clean_table.
+   Copyright (C) 2019 Gonzalo Pérez de Olaguer Córdoba <salo@gpoc.es>
 
 This file is part of gputils.
 
@@ -174,9 +177,12 @@ gp_cofflink_clean_table(gp_object_t *Object, symbol_table_t *Symbols)
   const gp_coffsymbol_t *var;
   const symbol_t        *sym;
   gp_symbol_t           *next;
+  int                    num_clean_errors;
 
   gp_debug("Cleaning symbol table.");
 
+  num_clean_errors = gp_real_num_errors();
+
   /* point all relocations to the symbol definitions */
   section = Object->section_list.first;
   while (section != NULL) {
@@ -186,28 +192,45 @@ gp_cofflink_clean_table(gp_object_t *Object, symbol_table_t *Symbols)
 
       if (gp_coffgen_is_external_symbol(symbol)) {
         /* This is an external symbol defined elsewhere. */
-        sym    = gp_sym_get_symbol(Symbols, symbol->name);
-        assert(sym != NULL);
-        var    = (const gp_coffsymbol_t *)gp_sym_get_symbol_annotation(sym);
-        assert(var != NULL);
+        sym = gp_sym_get_symbol(Symbols, symbol->name);
+        if (sym == NULL) {
+          gp_error("External symbol \"%s\" in section \"%s\" not found.", symbol->name, section->name);
+          goto _continue;
+        }
+
+        var = (const gp_coffsymbol_t *)gp_sym_get_symbol_annotation(sym);
+        if (var == NULL) {
+          gp_error("External symbol \"%s\" in section \"%s\" not annotated.", symbol->name, section->name);
+          goto _continue;
+        }
+
+        if (var->symbol == NULL) {
+          gp_error("External symbol \"%s\" in section \"%s\" not provided.", symbol->name, section->name);
+          goto _continue;
+        }
+
         symbol = var->symbol;
-        assert(symbol != NULL);
         relocation->symbol = symbol;
       }
 
+_continue:
       relocation = relocation->next;
     }
 
     section = section->next;
   }
 
+  if (gp_real_num_errors() > num_clean_errors) {
+    exit(1);
+  }
+
   symbol = Object->symbol_list.first;
   while (symbol != NULL) {
     next = symbol->next;
 
     if (gp_coffgen_is_external_symbol(symbol)) {
       gp_debug("  removed symbol \"%s\"", symbol->name);
-      gp_coffgen_del_symbol(Object, symbol);
+      gp_coffgen_del_symbol(Object, symbol, true);
     }
 
     symbol = next;
@@ -265,7 +288,7 @@ gp_cofflink_combine_overlay(gp_object_t *Object, gp_boolean Remove_symbol)
 
         /* Remove the section symbol. */
         if (Remove_symbol) {
-          gp_coffgen_del_symbol(Object, second->symbol);
+          gp_coffgen_del_symbol(Object, second->symbol, true);
         }
 
         /* Update the symbol table */
@@ -1570,6 +1593,7 @@ _patch_addr(gp_object_t *Object, gp_section_t *Section, const gp_reloc_t *Reloca
   int                bank;
   int                page;
   gp_boolean         write_data;
+  const insn_t      *instruction;
 
   class     = Object->class;
   num_pages = gp_processor_num_pages(Object->processor);
@@ -1602,9 +1626,23 @@ _patch_addr(gp_object_t *Object, gp_section_t *Section, const gp_reloc_t *Reloca
       data = class->reloc_goto(value);
       break;
 
-    case RELOC_LOW:
-      data = value & 0xff;
+    case RELOC_LOW: {
+      instruction = class->find_insn(class, current_value);
+
+      if (instruction == NULL)  {
+        gp_error("No instruction for %#x at %#x(%s/%s)", current_value,
+                 byte_addr, Section->name, symbol->name);
+        return;
+      }
+
+      if (instruction->class == INSN_CLASS_LIT8) {
+        data = value & 0xff;
+      }
+      else {
+        data = class->reloc_f(value);
+      }
       break;
+    }
 
     case RELOC_HIGH:
       data = class->reloc_high(FlagIsSet(symbol->section->flags, STYP_ROM_AREA), value);
